@@ -19,6 +19,7 @@
 #define GPARTED_DIALOG_BASE_PARTITION_H
 
 #include "Frame_Resizer_Extended.h"
+#include "FileSystem.h"
 #include "Partition.h"
 
 #include <gtkmm/dialog.h>
@@ -92,6 +93,7 @@ protected:
 	bool fixed_start, GRIP ;
 	double before_value ;
 	FS fs ;
+	FS_Limits fs_limits;  // Working copy of file system min/max size limits
 
 private:
 	Dialog_Base_Partition( const Dialog_Base_Partition & src );              // Not implemented copy constructor
