@@ -66,10 +66,10 @@ private:
 	Gtk::Button *cancelbutton;
 	
 	Glib::RefPtr<Gdk::Pixbuf> icon_execute ;
-	Glib::RefPtr<Gdk::Pixbuf> icon_succes ;
+	Glib::RefPtr<Gdk::Pixbuf> icon_success;
 	Glib::RefPtr<Gdk::Pixbuf> icon_error ;
 	Glib::RefPtr<Gdk::Pixbuf> icon_info ;
-	Glib::RefPtr<Gdk::Pixbuf> icon_n_a ;
+	Glib::RefPtr<Gdk::Pixbuf> icon_warning;
 
 	Glib::RefPtr<Gtk::TreeStore> treestore_operations;
 	
