@@ -31,6 +31,15 @@
 namespace GParted
 {
 
+enum CUSTOM_TEXT
+{
+	CTEXT_NONE,
+	CTEXT_ACTIVATE_FILESYSTEM,       // Activate text ('Mount', 'Swapon', VG 'Activate', ...)
+	CTEXT_DEACTIVATE_FILESYSTEM,     // Deactivate text ('Unmount', 'Swapoff', VG 'Deactivate', ...)
+	CTEXT_CHANGE_UUID_WARNING,       // Warning to print when changing UUIDs
+	CTEXT_RESIZE_DISALLOWED_WARNING  // File system resizing currently disallowed reason
+};
+
 // Minimum and maximum file system size limits
 struct FS_Limits
 {
@@ -106,8 +115,8 @@ public:
 	FileSystem() ;
 	virtual ~FileSystem() {}
 
-	virtual const Glib::ustring get_custom_text( CUSTOM_TEXT ttype, int index = 0 ) const;
-	static const Glib::ustring get_generic_text( CUSTOM_TEXT ttype, int index = 0 ) ;
+	virtual const Glib::ustring & get_custom_text( CUSTOM_TEXT ttype, int index = 0 ) const;
+	static const Glib::ustring & get_generic_text( CUSTOM_TEXT ttype, int index = 0 );
 
 	virtual FS get_filesystem_support() = 0 ;
 	virtual FS_Limits get_filesystem_limits( const Partition & partition ) const  { return fs_limits; };
