@@ -24,6 +24,7 @@
 #include "Partition.h"
 #include "PartitionLUKS.h"
 #include "PartitionVector.h"
+#include "Utils.h"
 
 #include <parted/parted.h>
 #include <vector>
@@ -58,14 +59,15 @@ public:
 	bool toggle_flag( const Partition & partition, const Glib::ustring & flag, bool state ) ;
 	
 	const std::vector<FS> & get_filesystems() const ;
-	const FS & get_fs( GParted::FILESYSTEM filesystem ) const ;
+	const FS & get_fs( FSType filesystem ) const;
 	static std::vector<Glib::ustring> get_disklabeltypes() ;
 	std::map<Glib::ustring, bool> get_available_flags( const Partition & partition ) ;
 	Glib::ustring get_libparted_version() ;
 	Glib::ustring get_thread_status_message() ;
 
-	static FileSystem * get_filesystem_object( FILESYSTEM filesystem );
-	static bool supported_filesystem( FILESYSTEM fstype );
+	static FileSystem * get_filesystem_object( FSType filesystem );
+	static bool supported_filesystem( FSType fstype );
+	static FS_Limits get_filesystem_limits( FSType fstype, const Partition & partition );
 	static bool filesystem_resize_disallowed( const Partition & partition ) ;
 	static void insert_unallocated( const Glib::ustring & device_path,
 	                                PartitionVector & partitions,
@@ -81,18 +83,18 @@ private:
 	void set_device_from_disk( Device & device, const Glib::ustring & device_path );
 	void set_device_serial_number( Device & device );
 	void set_device_partitions( Device & device, PedDevice* lp_device, PedDisk* lp_disk ) ;
-	void set_device_one_partition( Device & device, PedDevice * lp_device, FILESYSTEM fstype,
+	void set_device_one_partition( Device & device, PedDevice * lp_device, FSType fstype,
 	                               std::vector<Glib::ustring> & messages );
 	void set_luks_partition( PartitionLUKS & partition );
 	void set_partition_label_and_uuid( Partition & partition );
-	static FILESYSTEM detect_filesystem_internal( PedDevice * lp_device, PedPartition * lp_partition );
-	static FILESYSTEM detect_filesystem( PedDevice * lp_device, PedPartition * lp_partition,
-	                                     std::vector<Glib::ustring> & messages );
+	static FSType detect_filesystem_internal( PedDevice * lp_device, PedPartition * lp_partition );
+	static FSType detect_filesystem( PedDevice * lp_device, PedPartition * lp_partition,
+	                                 std::vector<Glib::ustring> & messages );
 	void read_label( Partition & partition ) ;
 	void read_uuid( Partition & partition ) ;
 	void set_mountpoints( Partition & partition );
 	bool set_mountpoints_helper( Partition & partition, const Glib::ustring & path );
-	bool is_busy( FILESYSTEM fstype, const Glib::ustring & path ) ;
+	bool is_busy( FSType fstype, const Glib::ustring & path );
 	void set_used_sectors( Partition & partition, PedDisk* lp_disk );
 	void mounted_set_used_sectors( Partition & partition ) ;
 #ifdef HAVE_LIBPARTED_FS_RESIZE
@@ -144,8 +146,13 @@ private:
 	                   const Partition & partition_new,
 	                   OperationDetail & operationdetail );
 	bool resize_move_partition( const Partition & partition_old,
-			       	    const Partition & partition_new,
-				    OperationDetail & operationdetail ) ;
+	                            const Partition & partition_new,
+	                            OperationDetail & operationdetail,
+	                            bool rollback_on_fail );
+	bool resize_move_partition_implement( const Partition & partition_old,
+	                                      const Partition & partition_new,
+	                                      Sector & new_start,
+	                                      Sector & new_end );
 	bool shrink_encryption( const Partition & partition_old,
 	                        const Partition & partition_new,
 	                        OperationDetail & operationdetail );
@@ -186,10 +193,10 @@ private:
 	                  OperationDetail & operationdetail,
 	                  Byte_Value & total_done,
 	                  bool cancel_safe );
-	void rollback_transaction( const Partition & partition_src,
-				   const Partition & partition_dst,
-				   OperationDetail & operationdetail,
-				   Byte_Value total_done ) ;
+	void rollback_move_filesystem( const Partition & partition_src,
+	                               const Partition & partition_dst,
+	                               OperationDetail & operationdetail,
+	                               Byte_Value total_done );
 
 	bool check_repair_filesystem( const Partition & partition, OperationDetail & operationdetail ) ;
 	bool check_repair_maximize( const Partition & partition,
@@ -201,6 +208,7 @@ private:
 	bool calculate_exact_geom( const Partition & partition_old,
 			           Partition & partition_new,
 				   OperationDetail & operationdetail ) ;
+	bool update_dmraid_entry( const Partition & partition_new, OperationDetail & operationdetail );
 	bool erase_filesystem_signatures( const Partition & partition, OperationDetail & operationdetail ) ;
 	bool update_bootsector( const Partition & partition, OperationDetail & operationdetail ) ;
 
@@ -208,6 +216,8 @@ private:
 	static void init_filesystems();
 	static void fini_filesystems();
 
+	void capture_libparted_messages( OperationDetail & operationdetail, bool success );
+
 	static bool flush_device( PedDevice * lp_device );
 	static bool get_device( const Glib::ustring & device_path, PedDevice *& lp_device, bool flush = false );
 	static bool get_disk( PedDevice *& lp_device, PedDisk *& lp_disk, bool strict = true );
@@ -223,7 +233,7 @@ private:
 	static PedExceptionOption ped_exception_handler( PedException * e ) ;
 
 	std::vector<FS> FILESYSTEMS ;
-	static std::map< FILESYSTEM, FileSystem * > FILESYSTEM_MAP ;
+	static std::map< FSType, FileSystem * > FILESYSTEM_MAP;
 	std::vector<PedPartitionFlag> flags;
 	std::vector<Glib::ustring> device_paths ;
 	bool probe_devices ;
