@@ -17,7 +17,9 @@
 #ifndef GPARTED_OPERATIONCREATE_H
 #define GPARTED_OPERATIONCREATE_H
 
-#include "../include/Operation.h"
+#include "Operation.h"
+#include "Partition.h"
+#include "PartitionVector.h"
 
 namespace GParted
 {
@@ -28,10 +30,14 @@ public:
 	OperationCreate( const Device & device,
 			 const Partition & partition_orig,
 			 const Partition & partition_new ) ;
-	
-	void apply_to_visual( std::vector<Partition> & partitions ) ;
+	virtual ~OperationCreate();
+
+	void apply_to_visual( PartitionVector & partitions );
 
 private:
+	OperationCreate( const OperationCreate & src );              // Not implemented copy constructor
+	OperationCreate & operator=( const OperationCreate & rhs );  // Not implemented copy assignment operator
+
 	void create_description() ;
 	bool merge_operations( const Operation & candidate );
 } ;
