@@ -114,15 +114,6 @@ enum SIZE_UNIT
 	UNIT_TIB	= 5
 } ;
 
-enum CUSTOM_TEXT
-{
-	CTEXT_NONE,
-	CTEXT_ACTIVATE_FILESYSTEM,		// Activate text ('Mount', 'Swapon', VG 'Activate', ...)
-	CTEXT_DEACTIVATE_FILESYSTEM,		// Deactivate text ('Unmount', 'Swapoff', VG 'Deactivate', ...)
-	CTEXT_CHANGE_UUID_WARNING,		// Warning to print when changing UUIDs
-	CTEXT_RESIZE_DISALLOWED_WARNING		// File system resizing currently disallowed reason
-} ;
-
 class Utils
 {
 public:
@@ -153,6 +144,11 @@ public:
 				    Glib::ustring & output,
 				    Glib::ustring & error,
 				    bool use_C_locale = false ) ;
+	static int execute_command( const Glib::ustring & command,
+	                            const char * input,
+	                            Glib::ustring & output,
+	                            Glib::ustring & error,
+				    bool use_C_locale = false );
 	static int get_failure_status( Glib::SpawnError & e );
 	static int decode_wait_status( int wait_status );
 	static Glib::ustring regexp_label( const Glib::ustring & text
