@@ -282,9 +282,14 @@ void Dialog_Progress::on_signal_show()
 
 			str_temp += "\n\n<i><b>" + Glib::ustring( _("IMPORTANT") ) + "</b>\n" ;
 			str_temp += _("If you want support, you need to provide the saved details!") ;
-			str_temp += "\n" + String::ucompose(
-					/* TO TRANSLATORS: looks like   See http://gparted.org/save-details.htm for more information. */
-					_("See %1 for more information."), "http://gparted.org/save-details.htm" ) + "</i>" ;
+			str_temp += "\n";
+			str_temp += String::ucompose(
+			                    /* TO TRANSLATORS: looks like
+			                     * See https://gparted.org/save-details.htm for more information.
+			                     */
+			                    _("See %1 for more information."),
+			                    "https://gparted.org/save-details.htm" );
+			str_temp += "</i>";
 		
 			dialog .set_secondary_text( str_temp, true ) ;
 			dialog .run() ;
