@@ -61,7 +61,7 @@ void Partition::Set( const Glib::ustring & device_path,
                      const Glib::ustring & partition,
                      int partition_number,
                      PartitionType type,
-                     FILESYSTEM filesystem,
+                     FSType filesystem,
                      Sector sector_start,
                      Sector sector_end,
                      Byte_Value sector_size,
@@ -198,7 +198,7 @@ void Partition::Set_Unallocated( const Glib::ustring & device_path,
 
 void Partition::set_unpartitioned( const Glib::ustring & device_path,
                                    const Glib::ustring & partition_path,
-                                   FILESYSTEM fstype,
+                                   FSType fstype,
                                    Sector length,
                                    Byte_Value sector_size,
                                    bool busy )
