@@ -29,30 +29,26 @@
 namespace GParted
 {
 
-const Glib::ustring fat16::Change_UUID_Warning [] =
-	{ _( "Changing the UUID might invalidate the Windows Product Activation (WPA) key"
-	   )
-	, _( "On FAT and NTFS file systems, the"
-	     " Volume Serial Number is used as the UUID."
-	     " Changing the Volume Serial Number on the Windows system"
-	     " partition, normally C:, might invalidate the WPA key."
-	     " An invalid WPA key will prevent login until you reactivate Windows."
-	   )
-	, _( "Changing the UUID on external storage media and non-system partitions"
-	     " is usually safe, but guarantees cannot be given."
-	   )
-	,    ""
-	} ;
-
-const Glib::ustring fat16::get_custom_text( CUSTOM_TEXT ttype, int index ) const
+const Glib::ustring & fat16::get_custom_text( CUSTOM_TEXT ttype, int index ) const
 {
+	static const Glib::ustring change_uuid_warning[] =
+		{ _("Changing the UUID might invalidate the Windows Product Activation "
+		    "(WPA) key"),
+		  _("On FAT and NTFS file systems, the Volume Serial Number is used as "
+		    "the UUID. Changing the Volume Serial Number on the Windows system "
+		    "partition, normally C:, might invalidate the WPA key. An invalid "
+		    "WPA key will prevent login until you reactivate Windows."),
+		  _("Changing the UUID on external storage media and non-system "
+		    "partitions is usually safe, but guarantees cannot be given."),
+		  ""
+		};
+
 	int i ;
 	switch ( ttype ) {
 		case CTEXT_CHANGE_UUID_WARNING :
-			for ( i = 0 ; i < index && Change_UUID_Warning[ i ] != "" ; i++ ) {
-				// Just iterate...
-			}
-			return Change_UUID_Warning [ i ] ;
+			for ( i = 0 ; i < index && change_uuid_warning[i] != "" ; i++ )
+				;  // Just iterate...
+			return change_uuid_warning[i];
 		default :
 			return FileSystem::get_custom_text( ttype, index ) ;
 	}
