@@ -22,10 +22,27 @@
 namespace GParted
 {
 
+const Glib::ustring & luks::get_custom_text( CUSTOM_TEXT ttype, int index ) const
+{
+	/* TO TRANSLATORS: these labels will be used in the partition menu */
+	static const Glib::ustring activate_text = _("Open Encryption");
+	static const Glib::ustring deactivate_text = _("Close Encryption");
+	static const Glib::ustring empty_text;
+
+	switch ( ttype )
+	{
+		case CTEXT_ACTIVATE_FILESYSTEM:
+			return index == 0 ? activate_text : empty_text;
+		case CTEXT_DEACTIVATE_FILESYSTEM:
+			return index == 0 ? deactivate_text : empty_text;
+		default:
+			return empty_text;
+	}
+}
+
 FS luks::get_filesystem_support()
 {
-	FS fs;
-	fs.filesystem = FS_LUKS;
+	FS fs( FS_LUKS );
 
 	fs.busy = FS::EXTERNAL;
 	fs.read = FS::EXTERNAL;
